@@ -44,7 +44,7 @@ FAST_TEST = False #: determines whether we skip slow tests or not
 # This list also determines the order in which tests will executed
 __all__ = [
 	'package', 'translations',
-	'datetimetz', 'utils', 'errors', 'signals',
+	'datetimetz', 'utils', 'errors', 'signals', 'actions',
 	'environ', 'fs',
 	'config', 'applications',
 	'parsing', 'formats', 'templates', 'objectmanager',
@@ -55,7 +55,7 @@ __all__ = [
 	'calendar', 'printtobrowser', 'versioncontrol', 'inlinecalculator',
 	'tasklist', 'tags', 'imagegenerators', 'tableofcontents',
 	'quicknote', 'attachmentbrowser', 'insertsymbol',
-	'sourceview', 'tableeditor',
+	'sourceview', 'tableeditor', 'bookmarksbar', 'spell',
 	'ipc'
 ]
 
@@ -272,11 +272,14 @@ class LoggingFilter(object):
 	def filter(self, record):
 		msg = record.getMessage()
 
-		if isinstance(self.message, tuple):
+		if self.message is None:
+			return False
+		elif isinstance(self.message, tuple):
 			return not any(msg.startswith(m) for m in self.message)
 		else:
 			return not msg.startswith(self.message)
 
+
 	def wrap_test(self, test):
 		self.__enter__()
 		test.addCleanup(self.__exit__)
