@@ -12,9 +12,13 @@ class TestTranslations(TestCase):
 		for file in ['translations/zim.pot'] + glob('translations/*.po'):
 			if verbose:
 				print 'Checking %s' % file
+
 			t = TranslationFile(file)
 
 			if file == 'translations/zim.pot':
+				text = open(file).read()
+				self.assertFalse('namespace' in text.lower())
+
 				pot_creation_date = t.headers['POT-Creation-Date']
 			else:
 				if not t.headers['POT-Creation-Date'] == pot_creation_date:
@@ -69,8 +73,11 @@ class TranslationMessage(object):
 	def check_format_strings(self):
 		'''Check format strings in msgid_plural and msgstr'''
 		if 'strftime' in self.comment:
-			return True # strftime format string
+			return self._check_strftime_string()
+		else:
+			return self._check_format_strings()
 
+	def _check_format_strings(self):
 		wanted = sorted( self._format_string_re.findall(self.msgid) )
 		if not wanted:
 			return True # no string format used
@@ -83,6 +90,18 @@ class TranslationMessage(object):
 		else:
 			return True
 
+	def _check_strftime_string(self):
+		for msg in self.msgstr:
+			if msg and not msg == '""':
+				for c in re.findall('\%(.)', msg):
+					if c not in 'aAwdbBmyYHIpMSfzZjUWcxX%':
+						# valid charaters based on doc for datetime module
+						# other characters may be valid depending on platform
+						# but not robust
+						return False
+		else:
+			return True
+
 
 class TranslationFile(object):
 
@@ -155,5 +174,6 @@ class TranslationFile(object):
 				'Error with format strings in %s msgid on line %i\n' % (self.file, message.lineno) + message.msgid
 
 
+
 if __name__ == '__main__':
 	TestTranslations().runTest(verbose=True)
