@@ -18,11 +18,65 @@ classes, but it can cooperate with these classes and use them as proxies.
 import inspect
 import weakref
 import logging
+import re
 
 import zim.errors
 
 logger = logging.getLogger('zim')
 
+
+# We want to switch between <Control> for linux and windows and
+# <Command> for OS X. The gtk solution is to use the abstract <Primary>
+# modifier key. Unfortunately, this is not supported in gtk before
+# version gtk_version 2.24.7. Therefore we try to detect whether this
+# abstract key is supported or not, and if not, we fall back to <Control>.
+#
+# Secondary use of the PRIMARY_MODIFIER constant is that it can be
+# shown in user menus.
+
+_accelerator_preparse_re = re.compile('(?i)<Primary>')
+
+def gtk_accelerator_preparse(code, force=False):
+	'''Pre-parse the accelerator code to change <Primary> into
+	<Control> or <Command> if <Primary> is not supported.
+	@param code: accelerator code
+	@param force: if C{True} <Primary> is replaced even if not needed
+	@returns: same or modified accelerator code
+	'''
+	if not code:
+		return code # tolerate None ...
+
+	m = _accelerator_preparse_re.search(code)
+	if m:
+		import gtk
+		x, mod = gtk.accelerator_parse('<Primary>')
+		if not mod:
+			# <Primary> is not supported - anyway to detect OS X?
+			return _accelerator_preparse_re.sub('<Control>', code)
+		elif force:
+			if mod == gtk.gdk.META_MASK:
+				return _accelerator_preparse_re.sub('<Command>', code)
+			else:
+				return _accelerator_preparse_re.sub('<Control>', code)
+		else:
+			return code
+	else:
+		return code
+
+
+# FIXME - temporary helper method - remove it again when all users are refactored
+def gtk_accelerator_preparse_list(actions):
+	myactions = []
+	for action in actions:
+		if len(action) > 3:
+			a = list(action)
+			a[3] = gtk_accelerator_preparse(a[3])
+			action = tuple(a)
+		myactions.append(action)
+	return myactions
+
+
+
 class Action(object):
 	'''Action, used by the L{action} decorator'''
 
@@ -35,7 +89,7 @@ class Action(object):
 		self.readonly = readonly
 		self.func = func
 		self._attr = (self.name, label, tooltip, stock)
-		self._accel = accelerator
+		self._accel = gtk_accelerator_preparse(accelerator)
 
 	def _assert_args(self, func):
 		args, varargs, keywords, defaults = inspect.getargspec(func)
