@@ -526,6 +526,7 @@ class Index(gobject.GObject):
 	def _connect(self):
 		self.db = sqlite3.connect(
 			str(self.dbfile), detect_types=sqlite3.PARSE_DECLTYPES)
+		self.db.execute('PRAGMA synchronous=OFF;')
 		self.db.row_factory = sqlite3.Row
 		self.db_commit = DBCommitContext(self.db)
 
@@ -757,6 +758,9 @@ class Index(gobject.GObject):
 		@param path: a L{Path} object
 		@returns: the L{IndexPath} object for C{path}
 		'''
+		_path = self.lookup_path(path)
+		if _path:
+			return _path
 		with self.db_commit:
 			return self._touch(path)
 
