@@ -180,9 +180,12 @@ class IndexExtension(ObjectExtension):
 	def _set_preferences(self):
 		self._current_preferences = self._serialize_rebuild_on_preferences()
 
-		string = self.preferences['labels'].strip(' ,')
-		if string:
-			self.task_labels = [s.strip() for s in self.preferences['labels'].split(',')]
+		if self.preferences['labels']:
+			self.task_labels = [
+				s.strip()
+					for s in self.preferences['labels'].split(',')
+						if s and not s.isspace()
+			]
 		else:
 			self.task_labels = []
 
@@ -607,7 +610,7 @@ class TasksParser(Visitor):
 		elif any(t.lower() in self.nonactionable_tags for t in tags):
 			actionable = False
 		elif self._matches_next_label(text) and parent_children:
-			previous = parent_children[-1]
+			previous = parent_children[-1][0]
 			actionable = not previous[0] # previous task not open
 		else:
 			actionable = True
@@ -899,7 +902,8 @@ class TaskListTreeView(BrowserTreeView):
 		self.append_column(column)
 		self.set_expander_column(column)
 
-		if gtk.gtk_version >= (2, 12, 0):
+		if gtk.gtk_version >= (2, 12) \
+		and gtk.pygtk_version >= (2, 12):
 			self.set_tooltip_column(self.TASK_COL)
 
 		# Rendering of the Date column
